@@ -2,4 +2,7 @@
 
 __author__ = """Chris B Chamberlain"""
 __email__ = 'chrisbc@artisan.co.nz'
-__version__ = '0.5.3'
+__version__ = '1.0.0'
+
+from .config import API_KEY, API_URL, S3_URL
+from .toshi_file import ToshiFile
